gxe.coh: Estimation of gene-environment interaction on the additive scale for cohort data
Description
Estimation of gene-environment interaction on the additive scale for cohort data
Usage
gxe.coh(aff, unaff)
Arguments
aff
a vector containing numbers affected individuals observed in the gene environment groups
, , and
unaff
a vector containing numbers of unaffected individuals observed in the gene environment groups
, , and
Value
GxE.coh
a list containing the interaction estimate,
the corresponding variance and
the boundaries of the 95% of the confidence interval
Details
see Nguyen et al. 2013
References
Making Medical Decisions in Dependence of Genetic Background: Estimation of the Utility of DNA Testing in Clinical, Pharmaco-Epidemiological or Genetic Studies. Nguyen TT, Schaefer H, Timmesfeld N. Genet Epidemiol. 2013 Apr 4. doi: 10.1002/gepi.21701